@@ -1,4 +1,4 @@
-import icos_face_leg_reduce_coord_gen
+from .icos_face_leg_reduce_coord_gen import icos_face_leg_reduce_coord_gen
 
 
 def icos_face_input_coord(radius: float, sigma: float):
